Django-Onfido
==============

.. image:: https://travis-ci.org/hugorodgerbrown/django-onfido.svg?branch=master
    :target: https://travis-ci.org/hugorodgerbrown/django-onfido

Django app for integration with the Onfido API (v2)

**This app is unstable and in development, please do not use yet**